==> mp3plot-0.5.1.tar.gz: mp3plot-0.5.1/src/mp3/bitrate.h <==
/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007, 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: bitrate.h 1637 2009-04-14 02:10:48Z  $

#ifndef MP3PLOT_MP3_BITRATE_H
#define MP3PLOT_MP3_BITRATE_H

#include <vector>

#include "../mp3_config.h"
#include "../common.h"

namespace mp3plot {

namespace mp3 {

    /*!
     * \brief Interface to the set of standard bitrates
     */
    class standard_bitrates {
    public:
        typedef std::vector<bitrate_t> bitrate_vector;
    private:
        static bool init_done;
        static void init();
        static bitrate_vector bitrates;
    public:
        /*!
         * \brief Returns a vector of the standard bitrates
         */
        static const bitrate_vector as_vector();

        /*!
         * \brief Returns the bitrate corresponding to a bitrate id
         * \remarks The id is the number used in the MP3 headers to refer to that bitrate
         * \param[in] bitrate_header_id Id of the bitrate (see remarks)
         */
        static bitrate_t get(uint8_t bitrate_header_id);

        /*!
         * \brief Returns the number of standard bitrates
         */
        static size_t number() {
            init();
            return as_vector().size();
        }

        /*!
         * \brief Returns the bad bitrate symbolic value
         * \remarks The bad bitrate has obviouly no bitrate associated, this value
         *          is used through the code to represet it
         */
        static bitrate_t bad_bitrate();
    };

    // Forward declaration
    /*!
     * \brief Output operator for bitrate vectors, for debugging purposes.
     * Prints a list that matches bitrate ids with the associated nominal bitrate.
     */
    std::ostream & operator<<(std::ostream &, const standard_bitrates::bitrate_vector &);

} // namespace mp3

} // namespace mp3plot

#endif // MP3PLOT_MP3_BITRATE_H
// vim:set ts=4 et ai:

==> mp3plot-0.6.0.tar.gz: mp3plot-0.6.0/src/mp3/bitrate.h <==
/*
 * mp3plot - Bitrate analysis tool
 *
 * Copyright (C) 2007, 2009 Toni Corvera
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

// $Id: bitrate.h 1344 2009-06-22 01:11:09Z toni $

#ifndef MP3PLOT_MP3_BITRATE_H
#define MP3PLOT_MP3_BITRATE_H

#include <vector>
#include <cassert>

#include "../mp3_config.h"
#include "../common.h"

namespace mp3plot {

namespace mp3 {

#if 0
    /*!
     * \brief Interface to the set of standard bitrates
     * \deprecated bitrate_translator should be used instead
     */
    class standard_bitrates {
    public:
        typedef std::vector<bitrate_t> bitrate_vector;
    private:
        static bool init_done;
        static void init();
        static bitrate_vector bitrates;
    public:
        /*!
         * \brief Returns a vector of the standard bitrates
         */
        static const bitrate_vector as_vector();

        /*!
         * \brief Returns the bitrate corresponding to a bitrate id
         * \remarks The id is the number used in the MP3 headers to refer to that bitrate
         * \param[in] bitrate_header_id Id of the bitrate (see remarks)
         */
        static bitrate_t get(uint8_t bitrate_header_id);

        /*!
         * \brief Returns the number of standard bitrates
         */
        static size_t number() {
            init();
            return as_vector().size();
        }

        /*!
         * \brief Returns the bad bitrate symbolic nominal value
         * \remarks The bad bitrate has obviouly no bitrate associated, this value
         *          is used through the code to represet it
         */
        static bitrate_t bad_bitrate();
    };
#endif

    /*!
     * \brief Maps a given bitrate index as presented in headers of MPEG audio
     *        frames to the actual nominal bitrate it represents.
     * \since 0.5.2, replaces standard_bitrates
     */
    class bitrate_translator {
    public:
        /*!
         * \brief Returns the bitrate corresponding to a bitrate id for a
         *        certain combination of mpeg version/layer
         * \remarks The id is the number used in the MPEG headers to refer
         *        to that bitrate
         * \param[in] bitrate_header_id Id of the bitrate (see remarks)
         * \param[in] ver MPEG version. Ids mean different things for different
         *                versions
         * \param[in] layer MPEG layer. Ids mean different things for different
         *                  layers
         */
        static bitrate_t get(uint8_t bitrate_header_id, mpeg_version_t ver, mpeg_layer_t layer);

        /*!
         * \brief Returns the number of standard bitrates
         * \deprecated This is a fixed value
         */
        static uint8_t number() {
            return 16;
        }

        /*!
         * \brief Returns the bad bitrate symbolic nominal value
         * \remarks The bad bitrate value is not a valid bitrate and is not
         *          part of the MPEG standard, this value is used though the
         *          code to represent a non-valid bitrate.
         */
        static bitrate_t bad_bitrate() {
            // Arch/specs sanity check
            assert( ((bitrate_t)0xFF) != ((bitrate_t)-1) );
            return static_cast<bitrate_t>(-1);
        }
    };

#if 0
    // Forward declaration
    /*!
     * \brief Output operator for bitrate vectors, for debugging purposes.
     * Prints a list that matches bitrate ids with the associated nominal bitrate.
     */
    std::ostream & operator<<(std::ostream &, const standard_bitrates::bitrate_vector &);
#endif

} // namespace mp3

} // namespace mp3plot

#endif // MP3PLOT_MP3_BITRATE_H
// vim:set ts=4 et ai:
